# pyshic
A package to help data crunshing from ozone measurement devices. Find the [Docs here](https://gosow9.github.io/pyshic/).

# Use
The package is deployed to Pypi so to install it just run:
```bash
pip install pyshic
```

# Contribution
Merge requests are happily welcome. Please test the code you want to supply or change. Thanks :)

